import Vue from 'vue'
import Router from 'vue-router'
import Login from '@/pages/Login'
import StudentSubmissionPage from '@/pages/student/StudentSubmissionPage'
import SubscriptionWorkPage from '@/pages/SubscriptionWorkPage'
import PageNotFound from '@/pages/PageNotFound'
import StartPageSelector from '@/pages/StartPageSelector'
import LayoutSelector from '@/pages/LayoutSelector'
import VueInstance from '@/main'

import store from '@/store/store'

Vue.use(Router)

function tutorOrReviewerOnly (to, from, next) {
  next()
  if (store.getters.isTutorOrReviewer) {
    next()
  } else {
    next(from.path)
    VueInstance.$notify({
      title: 'Access denied',
      text: "You don't have permission to view this.",
      type: 'error'
    })
  }
}

const router = new Router({
  routes: [
    {
      path: '/login/',
      name: 'login',
      component: Login
    },
    {
      path: '',
      redirect: 'home',
      component: LayoutSelector,
      children: [
        {
          path: 'home',
          name: 'home',
          component: StartPageSelector
        },
        {
          path: 'subscription/:pk',
          name: 'subscription',
          beforeEnter: tutorOrReviewerOnly,
          component: SubscriptionWorkPage
        },
        {
          path: 'submission/:id',
          component: StudentSubmissionPage
        }
      ]
    },
    {
      path: '*',
      name: 'page-not-found',
      component: PageNotFound
    }
  ]
})

export default router
