import Vuex from 'vuex'
import Vue from 'vue'
import createPersistedState from 'vuex-persistedstate'

import studentPage from './modules/student-page'
import submissionNotes from './modules/submission-notes'
import authentication from './modules/authentication'
import ui from './modules/ui'

import actions from './actions'
import getters from './getters'
import mutations from '@/store/mutations'
import {lastInteraction} from '@/store/util/lastInteractionPlugin'

Vue.use(Vuex)

export function initialState () {
  return {
    lastAppInteraction: Date.now(),
    examTypes: {},
    submissionTypes: {},
    submissions: {},
    feedback: {},
    subscriptions: {},
    assignments: {}
  }
}

export const persistedStateKey = 'grady'

const store = new Vuex.Store({
  // TODO only enable this in dev and not in deployment (use env variable)
  strict: true,
  modules: {
    authentication,
    studentPage,
    submissionNotes,
    ui
  },
  plugins: [
    createPersistedState({
      key: persistedStateKey,
      storage: window.sessionStorage,
      // authentication.token is manually saved since using it with this plugin caused issues
      // when manually reloading the page
      paths: Object.keys(initialState()).concat(
        ['ui', 'studentPage', 'submissionNotes', 'authentication.username', 'authentication.userRole',
          'authentication.jwtTimeDelta'])
    }),
    lastInteraction],
  actions,
  getters,
  mutations,
  state: initialState()
})

export default store
